Welcome to sng’s documentation! — Startup Name Generator (sng) 0.3 documentation

# Welcome to sng’s documentation!

The `sng` package (short for “Startup Name Generator”) is hosted on GitHub. This is its documentation.

Contents:

- Introduction
  - Summary
  - Supplied wordlists
  - Background
- Installation
  - Install from GitHub
  - Install from PyPI
- Quickstart
  - Prepare and train the model
  - Save and load the model for later
- Discussion
  - Data preprocessing
  - The RNN architecture
  - Sampling Temperature
- Modules
  - Config
  - Generator
  - Wordlists

# Indices and tables

- Index
- Module Index
- Search Page